==> oscars_mgmnt_clms-0.0.5.dev20240208+28-py3-none-any.whl: oscars_mgmnt_clms/geometry/tiles.py <==
"""
Created on 02 Jully 2019

@author: Tonneau Stephane
"""

import re


class TileInfo(object):
    """class that deals with tilling schemas"""

    XY = "XY"
    REGEXP = {"XY": r".*_X(\d\d)Y(\d\d)_.*"}
    OUTEXP = {"XY": "X{}Y{}"}
    FILTEREXP = {"XY": r".*(_X\d\dY\d\d_).*"}

    @classmethod
    def get_filter(cls, value):
        """
        class method that returns the regular expression used for a given
        tile schema.

        :param value: the regular expression used for a given tile schema
        :type value: a string
        """
        return cls.FILTEREXP[value] if value in cls.FILTEREXP else None

    @classmethod
    def get(cls, value):
        """ class method that determines the tilling schema to use and fix 
        the bounding box geometry description accordingly.

        :param value: a string representing a specific tile
        :type value: a string
        """
        for key, keyval in cls.REGEXP.items():
            match = re.search(keyval, value)
            if ((match) and (len(match.groups()) > 1)):
                tile_info = TileInfo()
                tile_info.coord_x = match.group(1)
                tile_info.coord_y = match.group(2)
                tile_info.schema = key
                return tile_info
        return None

    def __init__(self):
        """
        Initialisator of the class
        """
        self.coord_x = None
        self.coord_y = None
        self.schema = None

    def __str__(self):
        """ returns the string representation of the object.

        :returns: a string representation of the object
        :rtype: string
        """
        if self.schema is not None:
            return self.OUTEXP[self.schema].format(self.coord_x, self.coord_y)
        return "-Unknown-"

    def fix_box(self, value):
        """ fixes the bounding box geometry description in a dictionary.

        :param value: the dictionary to update with bbox coordinates
        :type value: a dictionary
        """
        if self.schema == self.XY:
            coord_x = int(self.coord_x)
            coord_y = int(self.coord_y)
            ystart = 75.000000
            xdecal = 0.002978
            value['westbbox'] = -180.0 + coord_x * 10.0
            value['southbbox'] = ystart - 10.0 + xdecal - coord_y * 10.0
            value['eastbbox'] = -170.0 - xdecal + coord_x * 10.0
            value['northbbox'] = ystart - coord_y * 10.0
            return self
        return None

==> oscars_mgmnt_clms-0.1.2.dev20240429+53-py3-none-any.whl: oscars_mgmnt_clms/geometry/tiles.py <==
"""
Created on 02 Jully 2019

@author: Tonneau Stephane
"""

import re


class TileInfo(object):
    """class that deals with tilling schemas"""

    XY = "XY"
    REGEXP = {"XY": r".*_X(\d\d)Y(\d\d)_.*"}
    OUTEXP = {"XY": "X{}Y{}"}
    FILTEREXP = {"XY": r".*(_X\d\dY\d\d_).*"}

    @classmethod
    def get_filter(cls, value):
        """
        class method that returns the regular expression used for a given
        tile schema.

        :param value: the regular expression used for a given tile schema
        :type value: a string
        """
        return cls.FILTEREXP[value] if value in cls.FILTEREXP else None

    @classmethod
    def get(cls, value):
        """class method that determines the tilling schema to use and fix
        the bounding box geometry description accordingly.

        :param value: a string representing a specific tile
        :type value: a string
        """
        for key, keyval in cls.REGEXP.items():
            match = re.search(keyval, value)
            if (match) and (len(match.groups()) > 1):
                tile_info = TileInfo()
                tile_info.coord_x = match.group(1)
                tile_info.coord_y = match.group(2)
                tile_info.schema = key
                return tile_info
        return None

    def __init__(self):
        """
        Initialisator of the class
        """
        self.coord_x = None
        self.coord_y = None
        self.schema = None

    def __str__(self):
        """returns the string representation of the object.

        :returns: a string representation of the object
        :rtype: string
        """
        if self.schema is not None:
            return self.OUTEXP[self.schema].format(self.coord_x, self.coord_y)
        return "-Unknown-"

    def fix_box(self, value):
        """fixes the bounding box geometry description in a dictionary.

        :param value: the dictionary to update with bbox coordinates
        :type value: a dictionary
        """
        if self.schema == self.XY:
            coord_x = int(self.coord_x)
            coord_y = int(self.coord_y)
            ystart = 75.000000
            xdecal = 0.002978
            value["westbbox"] = -180.0 + coord_x * 10.0
            value["southbbox"] = ystart - 10.0 + xdecal - coord_y * 10.0
            value["eastbbox"] = -170.0 - xdecal + coord_x * 10.0
            value["northbbox"] = ystart - coord_y * 10.0
            return self
        return None
